@@ -13,16 +13,11 @@ import typing as t
 import pytest
 
 from libvcs import exc
-from libvcs._internal.run import run
+from libvcs._internal.run import _ENV, run
 from libvcs.sync.git import GitRemote, GitSync
 from libvcs.sync.hg import HgSync
 from libvcs.sync.svn import SvnSync
 
-if t.TYPE_CHECKING:
-    from typing import TypeAlias
-
-    from libvcs._internal.run import _ENV
-
 
 class MaxUniqueRepoAttemptsExceeded(exc.LibVCSException):
     """Raised when exceeded threshold of attempts to find a unique repo destination."""
@@ -159,9 +154,6 @@ def gitconfig(
     """Return git configuration, pytest fixture."""
     gitconfig = user_path / ".gitconfig"
 
-    if gitconfig.exists():
-        return gitconfig
-
     gitconfig.write_text(
         textwrap.dedent(
             f"""
@@ -170,6 +162,8 @@ def gitconfig(
     name = {vcs_name}
   [color]
     diff = auto
+  [protocol "file"]
+    allow = always
     """,
         ),
         encoding="utf-8",
@@ -186,6 +180,7 @@ def set_gitconfig(
 ) -> pathlib.Path:
     """Set git configuration."""
     monkeypatch.setenv("GIT_CONFIG", str(gitconfig))
+    monkeypatch.setenv("GIT_CONFIG_GLOBAL", str(gitconfig))  # For child processes
     return gitconfig
 
 
@@ -270,7 +265,7 @@ def unique_repo_name(remote_repos_path: pathlib.Path, max_retries: int = 15) ->
         return remote_repo_name
 
 
-InitCmdArgs: TypeAlias = list[str] | None
+InitCmdArgs: t.TypeAlias = list[str] | None
 
 
 class CreateRepoPostInitFn(t.Protocol):
@@ -704,6 +699,7 @@ def git_repo(
     projects_path: pathlib.Path,
     git_remote_repo: pathlib.Path,
     set_gitconfig: pathlib.Path,
+    set_home: None,  # Needed for child processes (e.g. submodules)
 ) -> GitSync:
     """Pre-made git clone of remote repo checked out to user's projects dir."""
     remote_repo_name = unique_repo_name(remote_repos_path=projects_path)
