@@ -25,6 +25,7 @@ import typing as t
 from urllib import parse as urlparse
 
 from libvcs import exc
+from libvcs._internal.types import StrPath
 from libvcs.cmd.git import Git
 from libvcs.sync.base import (
     BaseSync,
@@ -32,9 +33,6 @@ from libvcs.sync.base import (
     convert_pip_url as base_convert_pip_url,
 )
 
-if t.TYPE_CHECKING:
-    from libvcs._internal.types import StrPath
-
 logger = logging.getLogger(__name__)
 
 
@@ -87,7 +85,7 @@ class GitRemote:
 
 
 GitSyncRemoteDict = dict[str, GitRemote]
-GitRemotesArgs = t.Union[None, GitSyncRemoteDict, dict[str, str]]
+GitRemotesArgs = None | GitSyncRemoteDict | dict[str, str]
 
 
 @dataclasses.dataclass
@@ -401,9 +399,9 @@ class GitSync(BaseSync):
             self.log.debug("No git revision set, defaulting to origin/master")
             symref = self.cmd.symbolic_ref(name="HEAD", short=True)
             git_tag = symref.rstrip() if symref else "origin/master"
-        self.log.debug(f"git_tag: {git_tag}")
+        self.log.debug("git_tag: %s", git_tag)
 
-        self.log.info(f"Updating to '{git_tag}'.")
+        self.log.info("Updating to '%s'.", git_tag)
 
         # Get head sha
         try:
@@ -416,14 +414,14 @@ class GitSync(BaseSync):
             self.log.exception("Failed to get the hash for HEAD")
             return
 
-        self.log.debug(f"head_sha: {head_sha}")
+        self.log.debug("head_sha: %s", head_sha)
 
         # If a remote ref is asked for, which can possibly move around,
         # we must always do a fetch and checkout.
         show_ref_output = self.cmd.show_ref(pattern=git_tag, check_returncode=False)
-        self.log.debug(f"show_ref_output: {show_ref_output}")
+        self.log.debug("show_ref_output: %s", show_ref_output)
         is_remote_ref = "remotes" in show_ref_output
-        self.log.debug(f"is_remote_ref: {is_remote_ref}")
+        self.log.debug("is_remote_ref: %s", is_remote_ref)
 
         # show-ref output is in the form "<sha> refs/remotes/<remote>/<tag>"
         # we must strip the remote from the tag.
@@ -441,8 +439,8 @@ class GitSync(BaseSync):
                 raise GitRemoteRefNotFound(git_tag=git_tag, ref_output=show_ref_output)
             git_remote_name = m.group("git_remote_name")
             git_tag = m.group("git_tag")
-        self.log.debug(f"git_remote_name: {git_remote_name}")
-        self.log.debug(f"git_tag: {git_tag}")
+        self.log.debug("git_remote_name: %s", git_remote_name)
+        self.log.debug("git_tag: %s", git_tag)
 
         # This will fail if the tag does not exist (it probably has not
         # been fetched yet).
@@ -456,7 +454,7 @@ class GitSync(BaseSync):
         except exc.CommandError as e:
             error_code = e.returncode if e.returncode is not None else 0
             tag_sha = ""
-        self.log.debug(f"tag_sha: {tag_sha}")
+        self.log.debug("tag_sha: %s", tag_sha)
 
         # Is the hash checkout out what we want?
         somethings_up = (error_code, is_remote_ref, tag_sha != head_sha)
@@ -467,7 +465,7 @@ class GitSync(BaseSync):
         try:
             process = self.cmd.fetch(log_in_real_time=True, check_returncode=True)
         except exc.CommandError:
-            self.log.exception(f"Failed to fetch repository '{url}'")
+            self.log.exception("Failed to fetch repository '%s'", url)
             return
 
         if is_remote_ref:
@@ -493,7 +491,7 @@ class GitSync(BaseSync):
             try:
                 process = self.cmd.checkout(branch=git_tag)
             except exc.CommandError:
-                self.log.exception(f"Failed to checkout tag: '{git_tag}'")
+                self.log.exception("Failed to checkout tag: '%s'", git_tag)
                 return
 
             # Rebase changes from the remote branch
@@ -537,7 +535,7 @@ class GitSync(BaseSync):
             try:
                 process = self.cmd.checkout(branch=git_tag)
             except exc.CommandError:
-                self.log.exception(f"Failed to checkout tag: '{git_tag}'")
+                self.log.exception("Failed to checkout tag: '%s'", git_tag)
                 return
 
         self.cmd.submodule.update(recursive=True, init=True, log_in_real_time=True)
@@ -556,13 +554,13 @@ class GitSync(BaseSync):
         """
         remotes = {}
 
-        cmd = self.cmd.remote.run()
-        ret: filter[str] = filter(None, cmd.split("\n"))
+        ret = self.cmd.remotes.ls()
 
-        for remote_name in ret:
-            remote = self.remote(remote_name)
+        for r in ret:
+            # FIXME: Cast to the GitRemote that sync uses, for now
+            remote = self.remote(r.remote_name)
             if remote is not None:
-                remotes[remote_name] = remote
+                remotes[r.remote_name] = remote
         return remotes
 
     def remote(self, name: str, **kwargs: t.Any) -> GitRemote | None:
@@ -578,7 +576,7 @@ class GitSync(BaseSync):
         Remote name and url in tuple form
         """
         try:
-            ret = self.cmd.remote.show(
+            ret = self.cmd.remotes.show(
                 name=name,
                 no_query_remotes=True,
                 log_in_real_time=True,
@@ -614,11 +612,12 @@ class GitSync(BaseSync):
             defines the remote URL
         """
         url = self.chomp_protocol(url)
+        remote_cmd = self.cmd.remotes.get(remote_name=name, default=None)
 
-        if self.remote(name) and overwrite:
-            self.cmd.remote.set_url(name=name, url=url, check_returncode=True)
+        if remote_cmd is not None and overwrite:
+            remote_cmd.set_url(url=url, check_returncode=True)
         else:
-            self.cmd.remote.add(name=name, url=url, check_returncode=True)
+            self.cmd.remotes.add(name=name, url=url, check_returncode=True)
 
         remote = self.remote(name=name)
         if remote is None:
